[pypy-commit] pypy gc-del: Convert to use minimark.

arigo noreply at buildbot.pypy.org
Sat Apr 27 13:45:16 CEST 2013


Author: Armin Rigo <arigo at tunes.org>
Branch: gc-del
Changeset: r63692:9cfe83160f91
Date: 2013-04-27 13:44 +0200
http://bitbucket.org/pypy/pypy/changeset/9cfe83160f91/

Log:	Convert to use minimark.

diff --git a/rpython/rtyper/lltypesystem/test/test_rffi.py b/rpython/rtyper/lltypesystem/test/test_rffi.py
--- a/rpython/rtyper/lltypesystem/test/test_rffi.py
+++ b/rpython/rtyper/lltypesystem/test/test_rffi.py
@@ -527,7 +527,7 @@
         fn = self.compile(f, [], gcpolicy='ref')
         assert fn() == len(d)
 
-    def test_nonmovingbuffer_semispace(self):
+    def test_nonmovingbuffer_minimark(self):
         d = 'cool data'
         def f():
             counter = 0
@@ -540,8 +540,8 @@
                 finally:
                     free_nonmovingbuffer(d, buf)
             return counter
-        fn = self.compile(f, [], gcpolicy='semispace')
-        # The semispace gc uses raw_malloc for its internal data structs
+        fn = self.compile(f, [], gcpolicy='minimark')
+        # The minimark gc uses raw_malloc for its internal data structs
         # but hopefully less than 30 times.  So we should get < 30 leaks
         # unless the get_nonmovingbuffer()/free_nonmovingbuffer() pair
         # leaks at each iteration.  This is what the following line checks.


More information about the pypy-commit mailing list